disconnect method
disconnect() asynchronously disconnects from the currently connected printer and returns a Boolean value afterwards with the result of the disconnect operation (i.e. success or failure).
This will also clear the value of "LastConnectedPrinterName" internally.
Implementation
Future<bool?> disconnect() async {
return await BradyFlutterPluginPlatform.instance.disconnect();
}