disconnectWithoutForget method

Future<bool?> disconnectWithoutForget()

disconnectWithoutForget() asynchronously disconnects from the currently connected printer and returns a Boolean value afterwards with the result of the disconnect operation (i.e. success or failure).

This will NOT clear the value of "LastConnectedPrinterName" internally.

Implementation

Future<bool?> disconnectWithoutForget() async {
  return await BradyFlutterPluginPlatform.instance.disconnectWithoutForget();
}