getAvailablePrinterUpdates method

Future<List<String?>> getAvailablePrinterUpdates()

getAvailablePrinterUpdates() returns a list of string representing all printer updates that occurred since the last time this method was called.

Implementation

Future<List<String?>> getAvailablePrinterUpdates() async {
  return await BradyFlutterPluginPlatform.instance
      .getAvailablePrinterUpdates();
}