getPreview method
getPreview(Int) takes an Integer that represents the width in screen pixels that the print preview should display as (on the UI).
Implementation
Future<String?> getPreview(int elementSize) async {
return await BradyFlutterPluginPlatform.instance.getPreview(elementSize);
}