getRibbonName method
getRibbonName() returns a String representing the ribbon installed in the printer (will return empty string if there is no ribbon). Only the M611 and M710 support ribbons.
Implementation
Future<String?> getRibbonName() async {
return await BradyFlutterPluginPlatform.instance.getRibbonName();
}