printBitmapWithDimensions method

Future<bool?> printBitmapWithDimensions(
  1. double bitmapWidthInInches,
  2. double labelLengthInInches,
  3. int copies,
  4. bool cutAfterEachLabel,
  5. bool isCollated,
  6. bool printTrailer,
)

printBitmapWithDimensions() asynchronously sends a print job of the currently set template or bitmap image to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).

Implementation

Future<bool?> printBitmapWithDimensions(
    double bitmapWidthInInches,
    double labelLengthInInches,
    int copies,
    bool cutAfterEachLabel,
    bool isCollated,
    bool printTrailer) async {
  return await BradyFlutterPluginPlatform.instance.printBitmapWithDimensions(
      bitmapWidthInInches,
      labelLengthInInches,
      copies,
      cutAfterEachLabel,
      isCollated,
      printTrailer);
}