setAutomaticShutoffTime method
setAutomaticShutoffTime() asynchronously sets the automatic shutdown time of the printer in minutes and returns a Boolean value afterwards with the result of the setAutomaticShutoffTime operation (i.e. success or failure).
Implementation
Future<bool?> setAutomaticShutoffTime(int minutes) async {
return await BradyFlutterPluginPlatform.instance
.setAutomaticShutoffTime(minutes);
}