setPlaceholderValue method
setPlaceholderValue(String, String) takes two Strings to set a placeholder with a specified value.
The first argument must be a String which matches the placeholder's name in Brady Workstation where the template was created. The second argument must be a String representing the value you want to set to the placeholder.
Implementation
Future<void> setPlaceholderValue(String placeholder, String value) async {
await BradyFlutterPluginPlatform.instance
.setPlaceholderValue(placeholder, value);
}