setTemplateWithBase64 method

Future<void> setTemplateWithBase64(
  1. String base64,
  2. bool isTemplate
)

setTemplateWithBase64(String, bool) takes a base64 string of data representing a template or image file and a boolean that tells the plugin if the file is a template.

If true, the back-end will treat the base64 string like a BWT or BWS file. If false, the back-end will treat the base64 string like a PNG, JPG, etc.

This is converted to useful information about the template in the back-end code. This method sets the current template being acted upon when setPlaceholderValue(String, String) or print() is called. Therefore, calling setTemplateWithBase64(String, bool) again will override any previous template that has been set.

Implementation

Future<void> setTemplateWithBase64(String base64, bool isTemplate) async {
  return await BradyFlutterPluginPlatform.instance
      .setTemplateWithBase64(base64, isTemplate);
}