feedSupply method
feedSupply() asynchronously makes the connected printer print one empty label and returns a Boolean value afterwards with the result of the feed operation(i.e. success or failure).
Implementation
Future<bool?> feedSupply() async {
return await BradyFlutterPluginPlatform.instance.feedSupply();
}