getHaveOwnership method
getHaveOwnership() returns a Boolean representing the mobile device's ownership of a nearby M211.
This will only ever return True when communicating with an M211. It is possible to fail a connection to an M211, but successfully gain ownership, hence this method's existence.
Implementation
Future<bool?> getHaveOwnership() async {
return await BradyFlutterPluginPlatform.instance.getHaveOwnership();
}