printBitmapWithDimensions method
printBitmapWithDimensions() asynchronously sends a print job of the currently set template or bitmap image to the printer that the app is currently connected to and returns a Boolean value afterwards with the result of the print operation (i.e. success or failure).
Implementation
Future<bool?> printBitmapWithDimensions(
double bitmapWidthInInches,
double labelLengthInInches,
int copies,
bool cutAfterEachLabel,
bool isCollated,
bool printTrailer) async {
return await BradyFlutterPluginPlatform.instance.printBitmapWithDimensions(
bitmapWidthInInches,
labelLengthInInches,
copies,
cutAfterEachLabel,
isCollated,
printTrailer);
}